@@ -4,6 +4,7 @@
 #include <panda/refcnt.h>
 #include <panda/function.h>
 #include <functional>
+#include "PerlTraceInfo.h"
 
 namespace xs {
 
@@ -13,7 +14,7 @@ struct DualTrace: public panda::Refcnt {
     DualTrace() noexcept {};
 
     panda::BacktraceInfoSP get_c_trace() noexcept;
-    panda::BacktraceInfoSP get_perl_trace() noexcept;
+    PerlTraceInfoSP        get_perl_trace() noexcept;
 
     void set_c_trace(BacktraceInfoFn&& producer) noexcept { c_trace_producer = std::move(producer); }
     void set_perl_trace(BacktraceInfoFn&& producer) noexcept { perl_trace_producer = std::move(producer); }
@@ -25,7 +26,7 @@ private:
     panda::BacktraceInfoSP c_trace_cached;
     BacktraceInfoFn c_trace_producer;
 
-    panda::BacktraceInfoSP perl_trace_cached;
+    PerlTraceInfoSP perl_trace_cached;
     BacktraceInfoFn perl_trace_producer;
 };
 
